@@ -94,7 +94,8 @@ class {package_name}Conan(Sense2File):
     def deb(self):
         ## copy *.deb to deb folder
         package_name = self.name
-        deb_file = package_name + ".deb"
+        package_version = self.version
+        deb_file = package_name + "_" + package_version + ".deb"
         self.copy(deb_file, dst=".", keep_path=False)
 
         if os.path.exists(package_name):
