@@ -91,6 +91,7 @@ def _create_aux_files(conanfile, copy_info):
 def _create_deb_file(conanfile):
     #### set folder name
     package_name = conanfile.name
+    package_version = conanfile.version
     debian_folder = package_name + "/DEBIAN"
     app_folder = package_name + "/sense2"
         
@@ -128,7 +129,7 @@ def _create_deb_file(conanfile):
         conanfile.run(add_bin_cmd)
 
     ## generate deb package in build
-    build_package_cmd = "dpkg-deb --build " + package_name
+    build_package_cmd = "dpkg-deb --build " + package_name + " " + package_name + "_" + package_version + ".deb" 
     conanfile.run(build_package_cmd)
 
     ## copy *.deb to deb folder
